/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ArtifactAllowlistConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#artifact_type ArtifactAllowlist#artifact_type}
    */
    readonly artifactType: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#created_at ArtifactAllowlist#created_at}
    */
    readonly createdAt?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#created_by ArtifactAllowlist#created_by}
    */
    readonly createdBy?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#id ArtifactAllowlist#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#metastore_id ArtifactAllowlist#metastore_id}
    */
    readonly metastoreId?: string;
    /**
    * artifact_matcher block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#artifact_matcher ArtifactAllowlist#artifact_matcher}
    */
    readonly artifactMatcher: ArtifactAllowlistArtifactMatcher[] | cdktf.IResolvable;
}
export interface ArtifactAllowlistArtifactMatcher {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#artifact ArtifactAllowlist#artifact}
    */
    readonly artifact: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#match_type ArtifactAllowlist#match_type}
    */
    readonly matchType: string;
}
export declare function artifactAllowlistArtifactMatcherToTerraform(struct?: ArtifactAllowlistArtifactMatcher | cdktf.IResolvable): any;
export declare class ArtifactAllowlistArtifactMatcherOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ArtifactAllowlistArtifactMatcher | cdktf.IResolvable | undefined;
    set internalValue(value: ArtifactAllowlistArtifactMatcher | cdktf.IResolvable | undefined);
    private _artifact?;
    get artifact(): string;
    set artifact(value: string);
    get artifactInput(): string | undefined;
    private _matchType?;
    get matchType(): string;
    set matchType(value: string);
    get matchTypeInput(): string | undefined;
}
export declare class ArtifactAllowlistArtifactMatcherList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ArtifactAllowlistArtifactMatcher[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ArtifactAllowlistArtifactMatcherOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist databricks_artifact_allowlist}
*/
export declare class ArtifactAllowlist extends cdktf.TerraformResource {
    static readonly tfResourceType = "databricks_artifact_allowlist";
    /**
    * Generates CDKTF code for importing a ArtifactAllowlist resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the ArtifactAllowlist to import
    * @param importFromId The id of the existing ArtifactAllowlist that should be imported. Refer to the {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the ArtifactAllowlist to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.32.0/docs/resources/artifact_allowlist databricks_artifact_allowlist} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ArtifactAllowlistConfig
    */
    constructor(scope: Construct, id: string, config: ArtifactAllowlistConfig);
    private _artifactType?;
    get artifactType(): string;
    set artifactType(value: string);
    get artifactTypeInput(): string | undefined;
    private _createdAt?;
    get createdAt(): number;
    set createdAt(value: number);
    resetCreatedAt(): void;
    get createdAtInput(): number | undefined;
    private _createdBy?;
    get createdBy(): string;
    set createdBy(value: string);
    resetCreatedBy(): void;
    get createdByInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metastoreId?;
    get metastoreId(): string;
    set metastoreId(value: string);
    resetMetastoreId(): void;
    get metastoreIdInput(): string | undefined;
    private _artifactMatcher;
    get artifactMatcher(): ArtifactAllowlistArtifactMatcherList;
    putArtifactMatcher(value: ArtifactAllowlistArtifactMatcher[] | cdktf.IResolvable): void;
    get artifactMatcherInput(): cdktf.IResolvable | ArtifactAllowlistArtifactMatcher[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
